@@ -180,7 +180,10 @@ def _get_string(data):
     return _get_c_string(data[4:])
 
 def _get_object(data):
-    return _bson_to_dict(data)
+    (object, data) = _bson_to_dict(data)
+    if "$ref" in object:
+        return (DBRef(object["$ref"], object["$id"]), data)
+    return (object, data)
 
 def _get_array(data):
     (obj, data) = _get_object(data)
@@ -349,8 +352,7 @@ def _element_to_bson(key, value):
             flags += "x"
         return "\x0B" + name + _make_c_string(pattern) + _make_c_string(flags)
     if isinstance(value, DBRef):
-        ns = _make_c_string(value.collection)
-        return "\x0C" + name + struct.pack("<i", len(ns)) + ns + _shuffle_oid(str(value.id))
+        return _element_to_bson(key, SON([("$ref", value.collection), ("$id", value.id)]))
     raise InvalidDocument("cannot convert value of type %s to bson" % type(value))
 
 def _dict_to_bson(dict):
